@@ -1,18 +1,5 @@
-# from geoAnalytics import csv2raster as c2r
-# from geoAnalytics.config import config
-# from shapely import geos, wkb, wkt
-# from osgeo import gdal
-# import numpy as Numeric
-# import pandas as pd
-# import subprocess
-# import psycopg2
-# import random
-# import glob
-# import sys
-# import os
-
-import csv2raster as c2r
-from config import config
+from geoAnalytics import csv2raster as c2r
+from geoAnalytics.config import config
 from shapely import geos, wkb, wkt
 from osgeo import gdal
 import numpy as Numeric
@@ -20,9 +7,22 @@ import pandas as pd
 import subprocess
 import psycopg2
 import random
+import glob
 import sys
 import os
 
+# import csv2raster as c2r
+# from config import config
+# from shapely import geos, wkb, wkt
+# from osgeo import gdal
+# import numpy as Numeric
+# import pandas as pd
+# import subprocess
+# import psycopg2
+# import random
+# import sys
+# import os
+
 
 class database:
 
@@ -124,6 +124,7 @@ class database:
                 query += 'b' + str(i) + ' float,'
             query += 'b' + str(totalBands) + ' float'
             curr.execute("create table " + repositoryName + "(" + query + ")")
+            curr.execute("CREATE INDEX index_" + repositoryName + "ON " + repositoryName + "USING GIST (geog)" )
             conn.commit()
             print('Repository created')
         except (Exception, psycopg2.DatabaseError) as error:
@@ -209,6 +210,7 @@ class database:
                 conn.close()
                 print('Repository connection closed.')
 
+
     def insertRaster(self, repositoryName, fileName, totalBands, scalingFactor, SRID=4326):
         """
         Insert a TIFF file into the database
@@ -550,3 +552,53 @@ class database:
         # gDal transform to geoTIFF
         df = database.kNearestPixels(repositoryName, X, Y, k, Bands)
         database.dataFrame2Raster(df, rasterFileName)
+
+    def getRepositorySize(self, tableName):
+        """
+        
+        """
+
+        try:
+            conn = None
+            # read database configuration
+            params = config()
+            # connect to the PostgreSQL database
+            conn = psycopg2.connect(**params)
+            query = "SELECT pg_size_pretty( pg_total_relation_size('" + tableName + "') );"
+            dataFrameEnvelope = pd.read_sql_query(query, conn)
+            print(dataFrameEnvelope.iloc[0]['pg_size_pretty'])
+            return dataFrameEnvelope.iloc[0]['pg_size_pretty']
+        except (Exception, psycopg2.DatabaseError) as error:
+            print(error)
+        finally:
+            if conn is not None:
+                conn.close()
+                print('Repository connection closed.')
+    
+    
+    def getSizeOfAllRepositories(self):
+        """
+        Get return the size of the repository/database/table
+
+        :param repositoryName: name of the repository
+        """
+
+        try:
+            conn = None
+            # read database configuration
+            params = config()
+            # connect to the PostgreSQL database
+            conn = psycopg2.connect(**params)
+            q1 = "select current_database();"
+            q2 = pd.read_sql_query(q1, conn)
+
+            query = " SELECT pg_size_pretty( pg_database_size('" + q2.iloc[0]['current_database'] + "') );"
+            dataFrameEnvelope = pd.read_sql_query(query, conn)
+            print(dataFrameEnvelope.iloc[0]['pg_size_pretty'])
+            return dataFrameEnvelope.iloc[0]['pg_size_pretty']
+        except (Exception, psycopg2.DatabaseError) as error:
+            print(error)
+        finally:
+            if conn is not None:
+                conn.close()
+                print('Repository connection closed.')
\ No newline at end of file
